@@ -1,10 +1,12 @@
 package lib::projectroot;
+use strict;
+
 use strict;
 use warnings;
 use 5.010;
 
 # ABSTRACT: easier loading of a project's local libs
-our $VERSION = "1.003";
+our $VERSION = "1.004";
 
 use FindBin qw();
 use Carp qw(carp);
@@ -12,7 +14,7 @@ use File::Spec::Functions qw(catdir splitdir);
 use local::lib qw();
 use lib qw();
 
-my $ROOT;
+our $ROOT;
 
 sub import {
     my $class = shift;
@@ -91,7 +93,7 @@ lib::projectroot - easier loading of a project's local libs
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
@@ -117,6 +119,9 @@ version 1.003
   # the same as above
   use lib::projectroot qw(lib local::lib=local extra=Your-OtherModule,Dark-PAN);
 
+  # if you want to know where the project-root is:
+  say lib::projectroot::ROOT;  # /home/domm/jobs/Some-Project
+
 =head1 DESCRIPTION
 
 I'm usually using a setup like this:
@@ -177,6 +182,8 @@ You can also define extra dists directly while loading C<lib::projectroot>:
       extra=MyHelperStuff,CoolLib-NotYetOnCPAN
   );
 
+You can access C<$lib::projectroot::ROOT> if you need to know where the projectroot actually is located (e.g. to load some assets)
+
 =head1 TODOs
 
 Some ideas for future releases:
